# DAA-PnC-Tamarin

Tamarin models for the paper "Integrating Privacy into the Electric Vehicle Charging Architecture" which is currently under review.

In the paper, we propose a privacy-preserving extension to the existing Plug and Charge (PnC) architecture. Here, we provide the Tamarin models we use for formal verification of the security and privacy properties of our proposed extension.

Our models are based on the models from the following paper:

Stephan Wesemeyer, Christopher J.P. Newton, Helen Treharne, Liqun Chen, Ralf Sasse, and Jorden Whitefield. 2020. Formal Analysis and Implementation of a TPM 2.0-based Direct Anonymous Attestation Scheme. In Proceedings of the 15th ACM Asia Conference on Computer and Communications Security (ASIA CCS '20). Association for Computing Machinery, New York, NY, USA, 784–798. DOI:https://doi.org/10.1145/3320269.3372197

(cf. https://github.com/tamarin-prover/tamarin-prover/tree/dddaccbe981343dde1a321ce0c908585d4525918/examples/asiaccs20-eccDAA)


The Tamarin prover (https://tamarin-prover.github.io/) is required to verify the model. Please consult the Tamarin-Prover Manual (https://tamarin-prover.github.io/manual/tex/tamarin-manual.pdf) for installation and usage instructions. In addition, Python is required for the oracles.


In the following, we list which property of our extension is addressed by which Tamarin model.

**Security_Properties**
| Security Property                       | Tamarin File(s)                    |
|:----------------------------------------|:-----------------------------------|
| $SR_2$ - Secure Credential Installation | daa_pnc_credential_installation.spthy |
| $SR_3$ - Secure Charge Autorization     | daa_pnc_charge_authorisation_online.spthy <br> daa_pnc_charge_authorisation_offline.spthy |
| $SR_4$ - Charge Data Authenticity       | daa_pnc_charge_authorisation_online.spthy <br> daa_pnc_charge_authorisation_offline.spthy |

**Privacy_Properties**
The files with the keyword *anonymity* in their file name contain a model for a weaker version of the properties.
| Privacy Property                                 | Tamarin File(s)                                                                                          | Oracle |
|:-------------------------------------------------|:---------------------------------------------------------------------------------------------------------|:-|
| $PR_2$ - Unlinkable Credential Installation      | daa_pnc_anonymity_credential_installation.spthy <br> daa_pnc_unlinkability_credential_installation.spthy | oracle_credential_installation.py |
| $PR_3$ - Unlinkable Charge Autorization          | daa_pnc_anonymity_charge_authorisation.spthy <br> daa_pnc_unlinkability_charge_authorisation.spthy       | oracle_charge_authorisation.py |
| $PR_4$ - Unlinkable CDRs                         | daa_pnc_anonymity_cdrs.spthy <br> daa_pnc_unlinkability_cdrs.spthy                                       | oracle_cdrs.py |
| $PR_5$ - Unlinkability of EV Users and Locations | daa_pnc_anonymity_ev_users_locations.spthy <br> daa_pnc_unlinkability_ev_users_locations.spthy           | oracle_ev_users_locations.py |
